package com.glxp.mipsdl.controller;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.glxp.mipsdl.client.ClientProcessor;
import com.glxp.mipsdl.req.base.UdiwmsQueryUdiInvProductsRequest;
import com.glxp.mipsdl.req.base.forthird.ForBasicProductsSearchFilter;
import com.glxp.mipsdl.req.base.forthird.ForInvOutScanCodeFilter;
import com.glxp.mipsdl.req.base.forthird.ForInvProductsFilter;
import com.glxp.mipsdl.res.BaseResponse;
import com.glxp.mipsdl.util.ResultVOUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 南靖县医院--提供给第三方系统调用的接口
 */
@Slf4j
@RestController
public class ExNjxyyController {

    /**
     * B001 查询指定科室高值/普耗库存
     * @param forInvProductsFilter
     * @return
     */
    @PostMapping("/ex/udiwms/inv/products/filter")
    public BaseResponse invProductsFilter(@RequestBody @Valid ForInvProductsFilter forInvProductsFilter) {
        if (ObjectUtil.isNull(forInvProductsFilter)) {
            return ResultVOUtils.error(500, "查询条件不能为空");
        }
        if (StrUtil.isEmpty(forInvProductsFilter.getUdiCode()) &&
                StrUtil.isEmpty(forInvProductsFilter.getNameCode()) &&
                StrUtil.isEmpty(forInvProductsFilter.getCpmctymc()) &&
                StrUtil.isEmpty(forInvProductsFilter.getBatchNo())&&
                StrUtil.isEmpty(forInvProductsFilter.getInvCode())&&
                StrUtil.isEmpty(forInvProductsFilter.getSupName())) {
            return ResultVOUtils.error(500, "查询条件不能为空！");
        }
        return ClientProcessor.getHttpClient().queryUdiInvProductsFilter(forInvProductsFilter);
    }


    /**
     * B002 查询耗材字典
     * @param forBasicProductsSearchFilter
     * @return
     */
    @PostMapping("/ex/basic/products/search")
    public BaseResponse basicProductsSearch(@RequestBody @Valid ForBasicProductsSearchFilter forBasicProductsSearchFilter) {
        if (ObjectUtil.isNull(forBasicProductsSearchFilter)) {
            return ResultVOUtils.error(500, "查询条件不能为空");
        }
        if (StrUtil.isEmpty(forBasicProductsSearchFilter.getUdiCode()) &&
                StrUtil.isEmpty(forBasicProductsSearchFilter.getNameCode()) &&
                StrUtil.isEmpty(forBasicProductsSearchFilter.getCpmctymc()) &&
                StrUtil.isEmpty(forBasicProductsSearchFilter.getMainId())&&
                StrUtil.isEmpty(forBasicProductsSearchFilter.getGgxh())) {
            return ResultVOUtils.error(500, "查询条件不能为空！");
        }
        return ClientProcessor.getHttpClient().queryUdiBasicProductsSearch(forBasicProductsSearchFilter);
    }

    /**
     * B003 高值耗材实时出库/退库
     * @param forInvOutScanCodeFilter
     * @return
     */
    @PostMapping("/ex/inv/out/scanCode")
    public BaseResponse invOutScanCode(@RequestBody @Valid ForInvOutScanCodeFilter forInvOutScanCodeFilter) {
        return ClientProcessor.getHttpClient().queryUdiInvOutScanCode(forInvOutScanCodeFilter);
    }


}
